# chrono - agendas system
# Copyright (C) 2016  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf.urls import url

from . import views

urlpatterns = [
    url(r'^$', views.homepage, name='chrono-manager-homepage'),
    url(
        r'^unavailability-calendars/$',
        views.unavailability_calendar_list,
        name='chrono-manager-unavailability-calendar-list',
    ),
    url(
        r'^unavailability-calendar/add/$',
        views.unavailability_calendar_add,
        name='chrono-manager-unavailability-calendar-add',
    ),
    url(
        r'^unavailability-calendar/(?P<pk>\d+)/$',
        views.unavailability_calendar_view,
        name='chrono-manager-unavailability-calendar-view',
    ),
    url(
        r'^unavailability-calendar/(?P<pk>\d+)/edit/$',
        views.unavailability_calendar_edit,
        name='chrono-manager-unavailability-calendar-edit',
    ),
    url(
        r'^unavailability-calendar/(?P<pk>\d+)/delete/$',
        views.unavailability_calendar_delete,
        name='chrono-manager-unavailability-calendar-delete',
    ),
    url(
        r'^unavailability-calendar/(?P<pk>\d+)/settings$',
        views.unavailability_calendar_settings,
        name='chrono-manager-unavailability-calendar-settings',
    ),
    url(
        r'^unavailability-calendar/(?P<pk>\d+)/export$',
        views.unavailability_calendar_export,
        name='chrono-manager-unavailability-calendar-export',
    ),
    url(
        r'^unavailability-calendar/(?P<pk>\d+)/add-unavailability$',
        views.unavailability_calendar_add_unavailability,
        name='chrono-manager-unavailability-calendar-add-unavailability',
    ),
    url(r'^resources/$', views.resource_list, name='chrono-manager-resource-list'),
    url(r'^resource/add/$', views.resource_add, name='chrono-manager-resource-add'),
    url(r'^resource/(?P<pk>\d+)/$', views.resource_view, name='chrono-manager-resource-view'),
    url(
        r'^resource/(?P<pk>\d+)/(?P<year>[0-9]{4})/(?P<month>[0-9]+)/$',
        views.resource_monthly_view,
        name='chrono-manager-resource-month-view',
    ),
    url(
        r'^resource/(?P<pk>\d+)/(?P<year>[0-9]{4})/(?P<month>[0-9]+)/(?P<day>[0-9]+)/$',
        views.resource_day_view,
        name='chrono-manager-resource-day-view',
    ),
    url(r'^resource/(?P<pk>\d+)/edit/$', views.resource_edit, name='chrono-manager-resource-edit'),
    url(r'^resource/(?P<pk>\d+)/delete/$', views.resource_delete, name='chrono-manager-resource-delete'),
    url(r'^categories/$', views.category_list, name='chrono-manager-category-list'),
    url(r'^category/add/$', views.category_add, name='chrono-manager-category-add'),
    url(r'^category/(?P<pk>\d+)/edit/$', views.category_edit, name='chrono-manager-category-edit'),
    url(r'^category/(?P<pk>\d+)/delete/$', views.category_delete, name='chrono-manager-category-delete'),
    url(r'^agendas/add/$', views.agenda_add, name='chrono-manager-agenda-add'),
    url(r'^agendas/import/$', views.agendas_import, name='chrono-manager-agendas-import'),
    url(r'^agendas/export/$', views.agendas_export, name='chrono-manager-agendas-export'),
    url(r'^agendas/(?P<pk>\d+)/$', views.agenda_view, name='chrono-manager-agenda-view'),
    url(
        r'^agendas/(?P<pk>\d+)/month/$',
        views.agenda_month_redirect_view,
        name='chrono-manager-agenda-month-redirect-view',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/(?P<year>[0-9]{4})/(?P<month>[0-9]+)/$',
        views.agenda_monthly_view,
        name='chrono-manager-agenda-month-view',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/(?P<year>[0-9]{4})/(?P<month>[0-9]+)/(?P<day>[0-9]+)/$',
        views.agenda_day_view,
        name='chrono-manager-agenda-day-view',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/open/$',
        views.agenda_open_events_view,
        name='chrono-manager-agenda-open-events-view',
    ),
    url(r'^agendas/(?P<pk>\d+)/settings$', views.agenda_settings, name='chrono-manager-agenda-settings'),
    url(r'^agendas/(?P<pk>\d+)/edit$', views.agenda_edit, name='chrono-manager-agenda-edit'),
    url(
        r'^agendas/(?P<pk>\d+)/booking-delays$',
        views.agenda_booking_delays,
        name='chrono-manager-agenda-booking-delays',
    ),
    url(r'^agendas/(?P<pk>\d+)/roles$', views.agenda_roles, name='chrono-manager-agenda-roles'),
    url(r'^agendas/(?P<pk>\d+)/delete$', views.agenda_delete, name='chrono-manager-agenda-delete'),
    url(r'^agendas/(?P<pk>\d+)/export$', views.agenda_export, name='chrono-manager-agenda-export'),
    url(r'^agendas/(?P<pk>\d+)/add-event$', views.agenda_add_event, name='chrono-manager-agenda-add-event'),
    url(r'^agendas/(?P<pk>\d+)/duplicate$', views.agenda_duplicate, name='chrono-manager-agenda-duplicate'),
    url(
        r'^agendas/(?P<pk>\d+)/import-events$',
        views.agenda_import_events,
        name='chrono-manager-agenda-import-events',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/export-events$',
        views.agenda_export_events,
        name='chrono-manager-agenda-export-events',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/notifications$',
        views.agenda_notifications_settings,
        name='chrono-manager-agenda-notifications-settings',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/reminder$',
        views.agenda_reminder_settings,
        name='chrono-manager-agenda-reminder-settings',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/reminder/preview/(?P<type>(email|sms))/$',
        views.agenda_reminder_preview,
        name='chrono-manager-agenda-reminder-preview',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/(?P<event_pk>\d+)/$',
        views.event_view,
        name='chrono-manager-event-view',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/(?P<event_pk>\d+)/edit$',
        views.event_edit,
        name='chrono-manager-event-edit',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/(?P<event_pk>\d+)/delete$',
        views.event_delete,
        name='chrono-manager-event-delete',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/events/(?P<event_pk>\d+)/cancel$',
        views.event_cancel,
        name='chrono-manager-event-cancel',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/event_cancellation_report/(?P<report_pk>\d+)/$',
        views.event_cancellation_report,
        name='chrono-manager-event-cancellation-report',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/event_cancellation_reports/$',
        views.event_cancellation_report_list,
        name='chrono-manager-event-cancellation-report-list',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/add-resource/$',
        views.agenda_add_resource,
        name='chrono-manager-agenda-add-resource',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/resource/(?P<resource_pk>\d+)/delete/$',
        views.agenda_delete_resource,
        name='chrono-manager-agenda-delete-resource',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/add-meeting-type$',
        views.agenda_add_meeting_type,
        name='chrono-manager-agenda-add-meeting-type',
    ),
    url(r'^meetingtypes/(?P<pk>\d+)/edit$', views.meeting_type_edit, name='chrono-manager-meeting-type-edit'),
    url(
        r'^meetingtypes/(?P<pk>\d+)/delete$',
        views.meeting_type_delete,
        name='chrono-manager-meeting-type-delete',
    ),
    url(
        r'^agendas/(?P<agenda_pk>\d+)/desk/(?P<pk>\d+)/add-time-period$',
        views.agenda_add_time_period,
        name='chrono-manager-agenda-add-time-period',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/add-time-period$',
        views.virtual_agenda_add_time_period,
        name='chrono-manager-virtual-agenda-add-time-period',
    ),
    url(r'^timeperiods/(?P<pk>\d+)/edit$', views.time_period_edit, name='chrono-manager-time-period-edit'),
    url(
        r'^timeperiods/(?P<pk>\d+)/delete$',
        views.time_period_delete,
        name='chrono-manager-time-period-delete',
    ),
    url(r'^agendas/(?P<pk>\d+)/add-desk$', views.agenda_add_desk, name='chrono-manager-agenda-add-desk'),
    url(r'^desks/(?P<pk>\d+)/edit$', views.desk_edit, name='chrono-manager-desk-edit'),
    url(r'^desks/(?P<pk>\d+)/delete$', views.desk_delete, name='chrono-manager-desk-delete'),
    url(
        r'^desk/(?P<pk>\d+)/unavailability-calendar/(?P<unavailability_calendar_pk>\d+)/toggle/$',
        views.unavailability_calendar_toggle_view,
        name='chrono-manager-unavailability-calendar-toggle-view',
    ),
    url(
        r'^agendas/(?P<agenda_pk>\d+)/desk/(?P<pk>\d+)/add-time-period-exception$',
        views.agenda_add_time_period_exception,
        name='chrono-manager-agenda-add-time-period-exception',
    ),
    url(
        r'^agendas/desk/(?P<pk>\d+)/import-exceptions-from-ics/$',
        views.desk_import_time_period_exceptions,
        name='chrono-manager-desk-add-import-time-period-exceptions',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/add-virtual-member$',
        views.agenda_add_virtual_member,
        name='chrono-manager-agenda-add-virtual-member',
    ),
    url(
        r'^virtual-members/(?P<pk>\d+)/delete$',
        views.virtual_member_delete,
        name='chrono-manager-virtual-member-delete',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/edit$',
        views.time_period_exception_edit,
        name='chrono-manager-time-period-exception-edit',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/delete$',
        views.time_period_exception_delete,
        name='chrono-manager-time-period-exception-delete',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/exception-extract-list$',
        views.time_period_exception_extract_list,
        name='chrono-manager-time-period-exception-extract-list',
    ),
    url(
        r'^time-period-exceptions/(?P<pk>\d+)/exception-list$',
        views.time_period_exception_list,
        name='chrono-manager-time-period-exception-list',
    ),
    url(
        r'^time-period-exceptions-source/(?P<pk>\d+)/delete$',
        views.time_period_exception_source_delete,
        name='chrono-manager-time-period-exception-source-delete',
    ),
    url(
        r'^time-period-exceptions-source/(?P<pk>\d+)/refresh$',
        views.time_period_exception_source_refresh,
        name='chrono-manager-time-period-exception-source-refresh',
    ),
    url(
        r'^time-period-exceptions-source/(?P<pk>\d+)/toggle$',
        views.time_period_exception_source_toggle,
        name='chrono-manager-time-period-exception-source-toggle',
    ),
    url(
        r'^time-period-exceptions-source/(?P<pk>\d+)/replace$',
        views.time_period_exception_source_replace,
        name='chrono-manager-time-period-exception-source-replace',
    ),
    url(
        r'^agendas/(?P<pk>\d+)/bookings/(?P<booking_pk>\d+)/cancel$',
        views.booking_cancel,
        name='chrono-manager-booking-cancel',
    ),
    url(
        r'^agendas/events.csv$',
        views.agenda_import_events_sample_csv,
        name='chrono-manager-sample-events-csv',
    ),
    url(r'^menu.json$', views.menu_json),
]
